package com.persagy.person.service;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.persagy.common.service.ISuperService;
import com.persagy.person.pojo.dto.SaasAccount;

/**
 * 账号信息
 * 
 * @version 1.0.0
 * @company persagy 
 * @author zhangqiankun
 * @date 2021-03-13 15:29:50
 */
public interface ISaasAccountService extends ISuperService<SaasAccount> {

	/**
	 * 获取账号信息 
	 * 
	 * @param id
	 * @param groupCode
	 * @param username
	 * @return
	 */
	SaasAccount getOne(String id, String groupCode, String username);
	
	/**
	 * 获取账号列表，此方法会关联出集团名称信息
	 * 
	 * @param saasAccount
	 * @param startRow
	 * @param size
	 * @return
	 */
	Page<SaasAccount> queryAccountPageList(SaasAccount saasAccount, int page, int size);
	
	/**
	 * 获取账号的查询条件
	 * 
	 * @param saasAccount
	 * @return
	 */
	LambdaQueryWrapper<SaasAccount> getQueryWrapper(SaasAccount saasAccount);
	
	/**
	 * 验证账号名称的唯一性
	 * 
	 * @param groupCode 这里先废弃，默认账号用户名全局唯一
	 * @param username
	 * @param mail
	 * @param phone
	 * @param id
	 * @param isUpdate，是否是更新时调用，true-时，id-必须存在
	 * @return
	 */
	boolean validAccountName(String username, String mail, String phone, String id, boolean isUpdate);


    /**
     * 获取账号的查询条件
     * @param saasAccount
     * @return
     */
    LambdaQueryWrapper<SaasAccount> getQueryWrapperByUsername(SaasAccount saasAccount);
}

